__version__ = "0.1.9"
"""
Top-level package for canml.

Expose the most common functions so users can do:
    from canml import load_blf, to_csv, to_parquet
"""

from .canmlio import load_dbc_files, iter_blf_chunks, load_blf, to_csv, to_parquet
from .canmlio import CanmlConfig

__all__ = [
    "load_dbc_files",
    "iter_blf_chunks",
    "load_blf",
    "to_csv",
    "to_parquet",
    "CanmlConfig",
    "__version__",
]
